PCB Environment: NetTopology Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
NetTopology Struct Reference

## Public Member Functions
void | create (Net &) const

## Data Fields
std::vector< std::vector< std::variant< Point_25, std::string > > > | Connections

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/Topology.hpp